from WebAppDIRAC.Lib.WebHandler import WebHandler


class ApplicationWizardHandler(WebHandler):
    DEFAULT_AUTHORIZATION = "authenticated"
